@@ -17,6 +17,28 @@ from .services import DB_INSTANCES, DB_CREDENTIALS
 from .textfile import TextFile
 
 
+def getSelects(sql):
+    sqlSelect = sql[sql.find("select") + 6:sql.find("from")]
+    i = 0
+    stack = []
+    rm = []
+    while i < len(sqlSelect):
+        if "(" == sqlSelect[i]:
+            stack.append(i)
+        elif ")" == sqlSelect[i]:
+            if len(stack) == 1:
+                rm.append((stack.pop(), i))
+            else:
+                stack.pop()
+        i += 1
+    rm.reverse()
+    for r1, r2 in rm:
+        sqlSelect = sqlSelect[0:r1] + sqlSelect[r2 + 1:]
+    sqlSelect = sqlSelect.replace(" ", "").replace(
+        "distinct", "").lower().split(",")
+    return sqlSelect
+
+
 class Database(object):
     """
     Classe principal. S'instancia per cada connexió a una base de dades.
@@ -60,10 +82,8 @@ class Database(object):
             self.local_infile = attributes['local_infile']
 
     def generate_one(self, sql):
-        sqlSelect = (sql[sql.find("select") + 6:sql.find("from")
-                         ].replace(" ", "").replace("distinct", "").lower().split(","))
+        sqlSelect = getSelects(sql)
         data = {}
-        print(sqlSelect)
         if len(sqlSelect) > 0:
             for select in sqlSelect:
                 if select in Database.TEMPLATE:
